@@ -24,7 +24,8 @@ from calculate.core.client.cert_func import new_key_req
 from calculate.core.client.function import get_ip_mac_type
 from calculate.core.datavars import DataVarsCore
 from calculate.lib.utils.files import (makeDirectory, pathJoin, readFile,
-                                       writeFile, isMount)
+                                       writeFile)
+from calculate.lib.utils.mount import isMount
 from calculate.core.server.admin import Admins
 import os
 import hashlib
